==> haskell-criterion-1.5.1.0-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.5.1.0
id: criterion-1.5.1.0-7DFB3gGxAO969CwzrhVT3a
key: criterion-1.5.1.0-7DFB3gGxAO969CwzrhVT3a
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
abi: 85fa2826e1cb98ebbaf34c9852d9b98b
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
import-dirs: /usr/lib/ghc-8.4.3/site-local/criterion-1.5.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/criterion-1.5.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-criterion
hs-libraries: HScriterion-1.5.1.0-7DFB3gGxAO969CwzrhVT3a
depends:
    aeson-1.4.0.0-1xR3EM2Xhm4Aau5GdgOB0b
    ansi-wl-pprint-0.6.8.2-IrT08V31eRK8A0Je2S5END base-4.11.1.0
    base-compat-batteries-0.10.1-A3WjyLJErgA6GYyWbHhtD binary-0.8.5.1
    bytestring-0.10.8.2 cassava-0.5.1.0-8lNeQvqDMUPBeSUGsIktzv
    code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V containers-0.5.11.0
    criterion-measurement-0.1.1.0-EWvVD7ozesR7jQDklM1iSH
    deepseq-1.4.3.0 directory-1.3.1.5
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8 filepath-1.4.2
    Glob-0.9.2-JA2Wi2KXENiYNgffORojv
    microstache-1.0.1.1-L5bNfkuCUsqHw7tlgwkSHn
    js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ
    js-jquery-3.3.1-9N7f18obHt7Gv4srrxKGOo mtl-2.2.2
    mwc-random-0.14.0.0-G3WB7Ur1ZQJ5WcBeaI4Sue
    optparse-applicative-0.14.2.0-K7gRnp080wgGVRM5iNUBl1
    parsec-3.1.13.0 statistics-0.14.0.2-1GR8yedf6e3G4oalAdxcv1
    text-1.2.3.0 time-1.8.0.2 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    vector-algorithms-0.7.0.4-5IwVwgBYaiLHifekCoPTVl
abi-depends: aeson-1.4.0.0-1xR3EM2Xhm4Aau5GdgOB0b=c22e056a410eb876f6f97788d58417ce
             ansi-wl-pprint-0.6.8.2-IrT08V31eRK8A0Je2S5END=f3cad6fdb79194c1feac8d9ccb8ffd58
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-batteries-0.10.1-A3WjyLJErgA6GYyWbHhtD=6dca245662c0c09b82ceb740dcaf94a9
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cassava-0.5.1.0-8lNeQvqDMUPBeSUGsIktzv=a931d08ea6bd74618244a6ec4c3276fd
             code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V=79049f84d9ede2f2865e34c7a6dfc923
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             criterion-measurement-0.1.1.0-EWvVD7ozesR7jQDklM1iSH=abef474e7b8facd8336b556a9f642c4a
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             Glob-0.9.2-JA2Wi2KXENiYNgffORojv=93f1d1e308ff663fbeb6d0f1acab0c7a
             microstache-1.0.1.1-L5bNfkuCUsqHw7tlgwkSHn=b3763809aa6cb0ec6a5ebfb5df92d5b4
             js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ=682f148b16a4228534fb18ce1bf6b5c5
             js-jquery-3.3.1-9N7f18obHt7Gv4srrxKGOo=820e0ac5d7009c511f54e7f6f484701b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             mwc-random-0.14.0.0-G3WB7Ur1ZQJ5WcBeaI4Sue=f9d32936c53f4ae9aeed1c5ddd994c91
             optparse-applicative-0.14.2.0-K7gRnp080wgGVRM5iNUBl1=f23942b3b87da5fbba8d301e58fc899a
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             statistics-0.14.0.2-1GR8yedf6e3G4oalAdxcv1=60d984d164e33904ebf8ae5aafb697b3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             vector-algorithms-0.7.0.4-5IwVwgBYaiLHifekCoPTVl=ca6dbcd1403e796b1ef13099b520f64e
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.5.1.0-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.5.1.0
id: criterion-1.5.1.0-9UnHFe3L9g6KXabjSp57xn
key: criterion-1.5.1.0-9UnHFe3L9g6KXabjSp57xn
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
abi: bc32291e2e8dc99d017597b29328a40a
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
import-dirs: /usr/lib/ghc-8.4.3/site-local/criterion-1.5.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/criterion-1.5.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-criterion
hs-libraries: HScriterion-1.5.1.0-9UnHFe3L9g6KXabjSp57xn
depends:
    aeson-1.4.1.0-Je86IRhAZ9i9fcEQGpo4BI
    ansi-wl-pprint-0.6.8.2-IrT08V31eRK8A0Je2S5END base-4.11.1.0
    base-compat-batteries-0.10.1-WCGvrszQMi5lVlZEwDwjH binary-0.8.5.1
    bytestring-0.10.8.2 cassava-0.5.1.0-3ZYXqaDZNjS5l91vSOMT9S
    code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V containers-0.5.11.0
    criterion-measurement-0.1.1.0-7tU9GQ0lyGKHjC131fkSFl
    deepseq-1.4.3.0 directory-1.3.1.5
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8 filepath-1.4.2
    Glob-0.9.3-Cjgy1gBQGreBHdDpbFbOC0
    microstache-1.0.1.1-DOQvwiu8YrC43WuoQK2AeE
    js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ
    js-jquery-3.3.1-1DdQshUsqF11tBbrN2KIVN mtl-2.2.2
    mwc-random-0.14.0.0-G3WB7Ur1ZQJ5WcBeaI4Sue
    optparse-applicative-0.14.3.0-3858SIdIcA6IDhFDNu1Ke4
    parsec-3.1.13.0 statistics-0.14.0.2-KyZIiBNI6MyG75pVOu1woJ
    text-1.2.3.0 time-1.8.0.2 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    vector-algorithms-0.8.0.0-GDWc64DH7nJ72e6auaL2EB
abi-depends: aeson-1.4.1.0-Je86IRhAZ9i9fcEQGpo4BI=e763a4a7c222101a91911389c36d4497
             ansi-wl-pprint-0.6.8.2-IrT08V31eRK8A0Je2S5END=f3cad6fdb79194c1feac8d9ccb8ffd58
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-batteries-0.10.1-WCGvrszQMi5lVlZEwDwjH=07815019646ea0bea4cd7b128dd8d3a1
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cassava-0.5.1.0-3ZYXqaDZNjS5l91vSOMT9S=876f28b670e664f52a2f7983d1d55710
             code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V=79049f84d9ede2f2865e34c7a6dfc923
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             criterion-measurement-0.1.1.0-7tU9GQ0lyGKHjC131fkSFl=e2188f965e1c3809d2e7eda117d1783e
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             Glob-0.9.3-Cjgy1gBQGreBHdDpbFbOC0=d043ffba096c687ce6042e6fddfabca1
             microstache-1.0.1.1-DOQvwiu8YrC43WuoQK2AeE=d3a8ff58a909b998b06fe6b33f0263c2
             js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ=682f148b16a4228534fb18ce1bf6b5c5
             js-jquery-3.3.1-1DdQshUsqF11tBbrN2KIVN=01b09ab338156b7709acfbca950719b6
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             mwc-random-0.14.0.0-G3WB7Ur1ZQJ5WcBeaI4Sue=f9d32936c53f4ae9aeed1c5ddd994c91
             optparse-applicative-0.14.3.0-3858SIdIcA6IDhFDNu1Ke4=aab631eb7769f669f53846ea7d62d855
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             statistics-0.14.0.2-KyZIiBNI6MyG75pVOu1woJ=501bf658aa0712bf8ea454556c9257cb
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             vector-algorithms-0.8.0.0-GDWc64DH7nJ72e6auaL2EB=30b13163652e7b1c06c024483f848519
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
